# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: a2a.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 29, 0, "", "a2a.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\ta2a.proto\x12\x06\x61\x32\x61.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x9e\x01\n\x18SendMessageConfiguration\x12\x1d\n\x15\x61\x63\x63\x65pted_output_modes\x18\x01 \x03(\t\x12\x39\n\x11push_notification\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.PushNotificationConfig\x12\x16\n\x0ehistory_length\x18\x03 \x01(\x05\x12\x10\n\x08\x62locking\x18\x04 \x01(\x08"\xbc\x01\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontext_id\x18\x02 \x01(\t\x12"\n\x06status\x18\x03 \x01(\x0b\x32\x12.a2a.v1.TaskStatus\x12#\n\tartifacts\x18\x04 \x03(\x0b\x32\x10.a2a.v1.Artifact\x12 \n\x07history\x18\x05 \x03(\x0b\x32\x0f.a2a.v1.Message\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct"\x87\x01\n\nTaskStatus\x12 \n\x05state\x18\x01 \x01(\x0e\x32\x11.a2a.v1.TaskState\x12(\n\x06update\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.MessageR\x07message\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"b\n\x04Part\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12 \n\x04\x66ile\x18\x02 \x01(\x0b\x32\x10.a2a.v1.FilePartH\x00\x12 \n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x10.a2a.v1.DataPartH\x00\x42\x06\n\x04part"Y\n\x08\x46ilePart\x12\x17\n\rfile_with_uri\x18\x01 \x01(\tH\x00\x12\x19\n\x0f\x66ile_with_bytes\x18\x02 \x01(\x0cH\x00\x12\x11\n\tmime_type\x18\x03 \x01(\tB\x06\n\x04\x66ile"1\n\x08\x44\x61taPart\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"\xbc\x01\n\x07Message\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x12\n\ncontext_id\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x1a\n\x04role\x18\x04 \x01(\x0e\x32\x0c.a2a.v1.Role\x12\x1d\n\x07\x63ontent\x18\x05 \x03(\x0b\x32\x0c.a2a.v1.Part\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nextensions\x18\x07 \x03(\t"\x9e\x01\n\x08\x41rtifact\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1b\n\x05parts\x18\x05 \x03(\x0b\x32\x0c.a2a.v1.Part\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nextensions\x18\x07 \x03(\t"\x9a\x01\n\x15TaskStatusUpdateEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\ncontext_id\x18\x02 \x01(\t\x12"\n\x06status\x18\x03 \x01(\x0b\x32\x12.a2a.v1.TaskStatus\x12\r\n\x05\x66inal\x18\x04 \x01(\x08\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct"\xb1\x01\n\x17TaskArtifactUpdateEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\ncontext_id\x18\x02 \x01(\t\x12"\n\x08\x61rtifact\x18\x03 \x01(\x0b\x32\x10.a2a.v1.Artifact\x12\x0e\n\x06\x61ppend\x18\x04 \x01(\x08\x12\x12\n\nlast_chunk\x18\x05 \x01(\x08\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct"t\n\x16PushNotificationConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x32\n\x0e\x61uthentication\x18\x04 \x01(\x0b\x32\x1a.a2a.v1.AuthenticationInfo":\n\x12\x41uthenticationInfo\x12\x0f\n\x07schemes\x18\x01 \x03(\t\x12\x13\n\x0b\x63redentials\x18\x02 \x01(\t"0\n\x0e\x41gentInterface\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\ttransport\x18\x02 \x01(\t"\xa2\x05\n\tAgentCard\x12\x18\n\x10protocol_version\x18\x10 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x1b\n\x13preferred_transport\x18\x0e \x01(\t\x12\x35\n\x15\x61\x64\x64itional_interfaces\x18\x0f \x03(\x0b\x32\x16.a2a.v1.AgentInterface\x12\'\n\x08provider\x18\x04 \x01(\x0b\x32\x15.a2a.v1.AgentProvider\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x19\n\x11\x64ocumentation_url\x18\x06 \x01(\t\x12/\n\x0c\x63\x61pabilities\x18\x07 \x01(\x0b\x32\x19.a2a.v1.AgentCapabilities\x12@\n\x10security_schemes\x18\x08 \x03(\x0b\x32&.a2a.v1.AgentCard.SecuritySchemesEntry\x12"\n\x08security\x18\t \x03(\x0b\x32\x10.a2a.v1.Security\x12\x1b\n\x13\x64\x65\x66\x61ult_input_modes\x18\n \x03(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_output_modes\x18\x0b \x03(\t\x12"\n\x06skills\x18\x0c \x03(\x0b\x32\x12.a2a.v1.AgentSkill\x12,\n$supports_authenticated_extended_card\x18\r \x01(\x08\x12.\n\nsignatures\x18\x11 \x03(\x0b\x32\x1a.a2a.v1.AgentCardSignature\x1aN\n\x14SecuritySchemesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.a2a.v1.SecurityScheme:\x02\x38\x01"2\n\rAgentProvider\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x14\n\x0corganization\x18\x02 \x01(\t"n\n\x11\x41gentCapabilities\x12\x11\n\tstreaming\x18\x01 \x01(\x08\x12\x1a\n\x12push_notifications\x18\x02 \x01(\x08\x12*\n\nextensions\x18\x03 \x03(\x0b\x32\x16.a2a.v1.AgentExtension"m\n\x0e\x41gentExtension\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\'\n\x06params\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct"\xaa\x01\n\nAgentSkill\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x10\n\x08\x65xamples\x18\x05 \x03(\t\x12\x13\n\x0binput_modes\x18\x06 \x03(\t\x12\x14\n\x0coutput_modes\x18\x07 \x03(\t\x12"\n\x08security\x18\x08 \x03(\x0b\x32\x10.a2a.v1.Security"o\n\x12\x41gentCardSignature\x12\x17\n\tprotected\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tsignature\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\'\n\x06header\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"l\n\x1aTaskPushNotificationConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x18push_notification_config\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.PushNotificationConfig"\x1a\n\nStringList\x12\x0c\n\x04list\x18\x01 \x03(\t"~\n\x08Security\x12.\n\x07schemes\x18\x01 \x03(\x0b\x32\x1d.a2a.v1.Security.SchemesEntry\x1a\x42\n\x0cSchemesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.a2a.v1.StringList:\x02\x38\x01"\xf1\x02\n\x0eSecurityScheme\x12?\n\x17\x61pi_key_security_scheme\x18\x01 \x01(\x0b\x32\x1c.a2a.v1.APIKeySecuritySchemeH\x00\x12\x43\n\x19http_auth_security_scheme\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.HTTPAuthSecuritySchemeH\x00\x12>\n\x16oauth2_security_scheme\x18\x03 \x01(\x0b\x32\x1c.a2a.v1.OAuth2SecuritySchemeH\x00\x12N\n\x1fopen_id_connect_security_scheme\x18\x04 \x01(\x0b\x32#.a2a.v1.OpenIdConnectSecuritySchemeH\x00\x12?\n\x14mtls_security_scheme\x18\x05 \x01(\x0b\x32\x1f.a2a.v1.MutualTlsSecuritySchemeH\x00\x42\x08\n\x06scheme"K\n\x14\x41PIKeySecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t"T\n\x16HTTPAuthSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12\x15\n\rbearer_format\x18\x03 \x01(\t"k\n\x14OAuth2SecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.a2a.v1.OAuthFlows\x12\x1b\n\x13oauth2_metadata_url\x18\x03 \x01(\t"O\n\x1bOpenIdConnectSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x1b\n\x13open_id_connect_url\x18\x02 \x01(\t".\n\x17MutualTlsSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t"\xf6\x01\n\nOAuthFlows\x12@\n\x12\x61uthorization_code\x18\x01 \x01(\x0b\x32".a2a.v1.AuthorizationCodeOAuthFlowH\x00\x12@\n\x12\x63lient_credentials\x18\x02 \x01(\x0b\x32".a2a.v1.ClientCredentialsOAuthFlowH\x00\x12-\n\x08implicit\x18\x03 \x01(\x0b\x32\x19.a2a.v1.ImplicitOAuthFlowH\x00\x12-\n\x08password\x18\x04 \x01(\x0b\x32\x19.a2a.v1.PasswordOAuthFlowH\x00\x42\x06\n\x04\x66low"\xce\x01\n\x1a\x41uthorizationCodeOAuthFlow\x12\x19\n\x11\x61uthorization_url\x18\x01 \x01(\t\x12\x11\n\ttoken_url\x18\x02 \x01(\t\x12\x13\n\x0brefresh_url\x18\x03 \x01(\t\x12>\n\x06scopes\x18\x04 \x03(\x0b\x32..a2a.v1.AuthorizationCodeOAuthFlow.ScopesEntry\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xb3\x01\n\x1a\x43lientCredentialsOAuthFlow\x12\x11\n\ttoken_url\x18\x01 \x01(\t\x12\x13\n\x0brefresh_url\x18\x02 \x01(\t\x12>\n\x06scopes\x18\x03 \x03(\x0b\x32..a2a.v1.ClientCredentialsOAuthFlow.ScopesEntry\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xa9\x01\n\x11ImplicitOAuthFlow\x12\x19\n\x11\x61uthorization_url\x18\x01 \x01(\t\x12\x13\n\x0brefresh_url\x18\x02 \x01(\t\x12\x35\n\x06scopes\x18\x03 \x03(\x0b\x32%.a2a.v1.ImplicitOAuthFlow.ScopesEntry\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xa1\x01\n\x11PasswordOAuthFlow\x12\x11\n\ttoken_url\x18\x01 \x01(\t\x12\x13\n\x0brefresh_url\x18\x02 \x01(\t\x12\x35\n\x06scopes\x18\x03 \x03(\x0b\x32%.a2a.v1.PasswordOAuthFlow.ScopesEntry\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xa9\x01\n\x12SendMessageRequest\x12/\n\x07request\x18\x01 \x01(\x0b\x32\x0f.a2a.v1.MessageB\x04\xe2\x41\x01\x02R\x07message\x12\x37\n\rconfiguration\x18\x02 \x01(\x0b\x32 .a2a.v1.SendMessageConfiguration\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"<\n\x0eGetTaskRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x0ehistory_length\x18\x02 \x01(\x05"!\n\x11\x43\x61ncelTaskRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"4\n$GetTaskPushNotificationConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"7\n\'DeleteTaskPushNotificationConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x92\x01\n\'CreateTaskPushNotificationConfigRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tconfig_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x38\n\x06\x63onfig\x18\x03 \x01(\x0b\x32".a2a.v1.TaskPushNotificationConfigB\x04\xe2\x41\x01\x02"\'\n\x17TaskSubscriptionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"^\n%ListTaskPushNotificationConfigRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"\x15\n\x13GetAgentCardRequest"g\n\x13SendMessageResponse\x12\x1c\n\x04task\x18\x01 \x01(\x0b\x32\x0c.a2a.v1.TaskH\x00\x12\'\n\x03msg\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.MessageH\x00R\x07messageB\t\n\x07payload"\xd6\x01\n\x0eStreamResponse\x12\x1c\n\x04task\x18\x01 \x01(\x0b\x32\x0c.a2a.v1.TaskH\x00\x12\'\n\x03msg\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.MessageH\x00R\x07message\x12\x36\n\rstatus_update\x18\x03 \x01(\x0b\x32\x1d.a2a.v1.TaskStatusUpdateEventH\x00\x12:\n\x0f\x61rtifact_update\x18\x04 \x01(\x0b\x32\x1f.a2a.v1.TaskArtifactUpdateEventH\x00\x42\t\n\x07payload"v\n&ListTaskPushNotificationConfigResponse\x12\x33\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32".a2a.v1.TaskPushNotificationConfig\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*\xfa\x01\n\tTaskState\x12\x1a\n\x16TASK_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14TASK_STATE_SUBMITTED\x10\x01\x12\x16\n\x12TASK_STATE_WORKING\x10\x02\x12\x18\n\x14TASK_STATE_COMPLETED\x10\x03\x12\x15\n\x11TASK_STATE_FAILED\x10\x04\x12\x18\n\x14TASK_STATE_CANCELLED\x10\x05\x12\x1d\n\x19TASK_STATE_INPUT_REQUIRED\x10\x06\x12\x17\n\x13TASK_STATE_REJECTED\x10\x07\x12\x1c\n\x18TASK_STATE_AUTH_REQUIRED\x10\x08*;\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\r\n\tROLE_USER\x10\x01\x12\x0e\n\nROLE_AGENT\x10\x02\x32\xba\n\n\nA2AService\x12\x63\n\x0bSendMessage\x12\x1a.a2a.v1.SendMessageRequest\x1a\x1b.a2a.v1.SendMessageResponse"\x1b\x82\xd3\xe4\x93\x02\x15"\x10/v1/message:send:\x01*\x12k\n\x14SendStreamingMessage\x12\x1a.a2a.v1.SendMessageRequest\x1a\x16.a2a.v1.StreamResponse"\x1d\x82\xd3\xe4\x93\x02\x17"\x12/v1/message:stream:\x01*0\x01\x12R\n\x07GetTask\x12\x16.a2a.v1.GetTaskRequest\x1a\x0c.a2a.v1.Task"!\xda\x41\x04name\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/{name=tasks/*}\x12[\n\nCancelTask\x12\x19.a2a.v1.CancelTaskRequest\x1a\x0c.a2a.v1.Task"$\x82\xd3\xe4\x93\x02\x1e"\x19/v1/{name=tasks/*}:cancel:\x01*\x12s\n\x10TaskSubscription\x12\x1f.a2a.v1.TaskSubscriptionRequest\x1a\x16.a2a.v1.StreamResponse"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/{name=tasks/*}:subscribe0\x01\x12\xc4\x01\n CreateTaskPushNotificationConfig\x12/.a2a.v1.CreateTaskPushNotificationConfigRequest\x1a".a2a.v1.TaskPushNotificationConfig"K\xda\x41\rparent,config\x82\xd3\xe4\x93\x02\x35"+/v1/{parent=task/*/pushNotificationConfigs}:\x06\x63onfig\x12\xae\x01\n\x1dGetTaskPushNotificationConfig\x12,.a2a.v1.GetTaskPushNotificationConfigRequest\x1a".a2a.v1.TaskPushNotificationConfig";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=tasks/*/pushNotificationConfigs/*}\x12\xbe\x01\n\x1eListTaskPushNotificationConfig\x12-.a2a.v1.ListTaskPushNotificationConfigRequest\x1a..a2a.v1.ListTaskPushNotificationConfigResponse"=\xda\x41\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=tasks/*}/pushNotificationConfigs\x12P\n\x0cGetAgentCard\x12\x1b.a2a.v1.GetAgentCardRequest\x1a\x11.a2a.v1.AgentCard"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/card\x12\xa8\x01\n DeleteTaskPushNotificationConfig\x12/.a2a.v1.DeleteTaskPushNotificationConfigRequest\x1a\x16.google.protobuf.Empty";\xda\x41\x04name\x82\xd3\xe4\x93\x02.*,/v1/{name=tasks/*/pushNotificationConfigs/*}B=\n\x11\x63om.google.a2a.v1B\x03\x41\x32\x41P\x01Z\x18google.golang.org/a2a/v1\xaa\x02\x06\x41\x32\x61.V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "a2a_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\021com.google.a2a.v1B\003A2AP\001Z\030google.golang.org/a2a/v1\252\002\006A2a.V1"
    )
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._loaded_options = None
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_options = b"8\001"
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["protected"]._loaded_options = None
    _globals["_AGENTCARDSIGNATURE"].fields_by_name[
        "protected"
    ]._serialized_options = b"\342A\001\002"
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["signature"]._loaded_options = None
    _globals["_AGENTCARDSIGNATURE"].fields_by_name[
        "signature"
    ]._serialized_options = b"\342A\001\002"
    _globals["_SECURITY_SCHEMESENTRY"]._loaded_options = None
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_options = b"8\001"
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_IMPLICITOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_IMPLICITOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_PASSWORDOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_PASSWORDOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_SENDMESSAGEREQUEST"].fields_by_name["request"]._loaded_options = None
    _globals["_SENDMESSAGEREQUEST"].fields_by_name[
        "request"
    ]._serialized_options = b"\342A\001\002"
    _globals["_GETTASKREQUEST"].fields_by_name["name"]._loaded_options = None
    _globals["_GETTASKREQUEST"].fields_by_name[
        "name"
    ]._serialized_options = b"\342A\001\002"
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "parent"
    ]._loaded_options = None
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "parent"
    ]._serialized_options = b"\342A\001\002"
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "config_id"
    ]._loaded_options = None
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "config_id"
    ]._serialized_options = b"\342A\001\002"
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "config"
    ]._loaded_options = None
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name[
        "config"
    ]._serialized_options = b"\342A\001\002"
    _globals["_A2ASERVICE"].methods_by_name["SendMessage"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SendMessage"
    ]._serialized_options = b'\202\323\344\223\002\025"\020/v1/message:send:\001*'
    _globals["_A2ASERVICE"].methods_by_name[
        "SendStreamingMessage"
    ]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SendStreamingMessage"
    ]._serialized_options = b'\202\323\344\223\002\027"\022/v1/message:stream:\001*'
    _globals["_A2ASERVICE"].methods_by_name["GetTask"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetTask"
    ]._serialized_options = (
        b"\332A\004name\202\323\344\223\002\024\022\022/v1/{name=tasks/*}"
    )
    _globals["_A2ASERVICE"].methods_by_name["CancelTask"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "CancelTask"
    ]._serialized_options = (
        b'\202\323\344\223\002\036"\031/v1/{name=tasks/*}:cancel:\001*'
    )
    _globals["_A2ASERVICE"].methods_by_name["TaskSubscription"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "TaskSubscription"
    ]._serialized_options = (
        b"\202\323\344\223\002\036\022\034/v1/{name=tasks/*}:subscribe"
    )
    _globals["_A2ASERVICE"].methods_by_name[
        "CreateTaskPushNotificationConfig"
    ]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "CreateTaskPushNotificationConfig"
    ]._serialized_options = b'\332A\rparent,config\202\323\344\223\0025"+/v1/{parent=task/*/pushNotificationConfigs}:\006config'
    _globals["_A2ASERVICE"].methods_by_name[
        "GetTaskPushNotificationConfig"
    ]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\004name\202\323\344\223\002.\022,/v1/{name=tasks/*/pushNotificationConfigs/*}"
    _globals["_A2ASERVICE"].methods_by_name[
        "ListTaskPushNotificationConfig"
    ]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "ListTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\006parent\202\323\344\223\002.\022,/v1/{parent=tasks/*}/pushNotificationConfigs"
    _globals["_A2ASERVICE"].methods_by_name["GetAgentCard"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetAgentCard"
    ]._serialized_options = b"\202\323\344\223\002\n\022\010/v1/card"
    _globals["_A2ASERVICE"].methods_by_name[
        "DeleteTaskPushNotificationConfig"
    ]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "DeleteTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\004name\202\323\344\223\002.*,/v1/{name=tasks/*/pushNotificationConfigs/*}"
    _globals["_TASKSTATE"]._serialized_start = 6235
    _globals["_TASKSTATE"]._serialized_end = 6485
    _globals["_ROLE"]._serialized_start = 6487
    _globals["_ROLE"]._serialized_end = 6546
    _globals["_SENDMESSAGECONFIGURATION"]._serialized_start = 202
    _globals["_SENDMESSAGECONFIGURATION"]._serialized_end = 360
    _globals["_TASK"]._serialized_start = 363
    _globals["_TASK"]._serialized_end = 551
    _globals["_TASKSTATUS"]._serialized_start = 554
    _globals["_TASKSTATUS"]._serialized_end = 689
    _globals["_PART"]._serialized_start = 691
    _globals["_PART"]._serialized_end = 789
    _globals["_FILEPART"]._serialized_start = 791
    _globals["_FILEPART"]._serialized_end = 880
    _globals["_DATAPART"]._serialized_start = 882
    _globals["_DATAPART"]._serialized_end = 931
    _globals["_MESSAGE"]._serialized_start = 934
    _globals["_MESSAGE"]._serialized_end = 1122
    _globals["_ARTIFACT"]._serialized_start = 1125
    _globals["_ARTIFACT"]._serialized_end = 1283
    _globals["_TASKSTATUSUPDATEEVENT"]._serialized_start = 1286
    _globals["_TASKSTATUSUPDATEEVENT"]._serialized_end = 1440
    _globals["_TASKARTIFACTUPDATEEVENT"]._serialized_start = 1443
    _globals["_TASKARTIFACTUPDATEEVENT"]._serialized_end = 1620
    _globals["_PUSHNOTIFICATIONCONFIG"]._serialized_start = 1622
    _globals["_PUSHNOTIFICATIONCONFIG"]._serialized_end = 1738
    _globals["_AUTHENTICATIONINFO"]._serialized_start = 1740
    _globals["_AUTHENTICATIONINFO"]._serialized_end = 1798
    _globals["_AGENTINTERFACE"]._serialized_start = 1800
    _globals["_AGENTINTERFACE"]._serialized_end = 1848
    _globals["_AGENTCARD"]._serialized_start = 1851
    _globals["_AGENTCARD"]._serialized_end = 2525
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_start = 2447
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_end = 2525
    _globals["_AGENTPROVIDER"]._serialized_start = 2527
    _globals["_AGENTPROVIDER"]._serialized_end = 2577
    _globals["_AGENTCAPABILITIES"]._serialized_start = 2579
    _globals["_AGENTCAPABILITIES"]._serialized_end = 2689
    _globals["_AGENTEXTENSION"]._serialized_start = 2691
    _globals["_AGENTEXTENSION"]._serialized_end = 2800
    _globals["_AGENTSKILL"]._serialized_start = 2803
    _globals["_AGENTSKILL"]._serialized_end = 2973
    _globals["_AGENTCARDSIGNATURE"]._serialized_start = 2975
    _globals["_AGENTCARDSIGNATURE"]._serialized_end = 3086
    _globals["_TASKPUSHNOTIFICATIONCONFIG"]._serialized_start = 3088
    _globals["_TASKPUSHNOTIFICATIONCONFIG"]._serialized_end = 3196
    _globals["_STRINGLIST"]._serialized_start = 3198
    _globals["_STRINGLIST"]._serialized_end = 3224
    _globals["_SECURITY"]._serialized_start = 3226
    _globals["_SECURITY"]._serialized_end = 3352
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_start = 3286
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_end = 3352
    _globals["_SECURITYSCHEME"]._serialized_start = 3355
    _globals["_SECURITYSCHEME"]._serialized_end = 3724
    _globals["_APIKEYSECURITYSCHEME"]._serialized_start = 3726
    _globals["_APIKEYSECURITYSCHEME"]._serialized_end = 3801
    _globals["_HTTPAUTHSECURITYSCHEME"]._serialized_start = 3803
    _globals["_HTTPAUTHSECURITYSCHEME"]._serialized_end = 3887
    _globals["_OAUTH2SECURITYSCHEME"]._serialized_start = 3889
    _globals["_OAUTH2SECURITYSCHEME"]._serialized_end = 3996
    _globals["_OPENIDCONNECTSECURITYSCHEME"]._serialized_start = 3998
    _globals["_OPENIDCONNECTSECURITYSCHEME"]._serialized_end = 4077
    _globals["_MUTUALTLSSECURITYSCHEME"]._serialized_start = 4079
    _globals["_MUTUALTLSSECURITYSCHEME"]._serialized_end = 4125
    _globals["_OAUTHFLOWS"]._serialized_start = 4128
    _globals["_OAUTHFLOWS"]._serialized_end = 4374
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"]._serialized_start = 4377
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"]._serialized_end = 4583
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_start = 4538
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_end = 4583
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"]._serialized_start = 4586
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"]._serialized_end = 4765
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_start = 4538
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_end = 4583
    _globals["_IMPLICITOAUTHFLOW"]._serialized_start = 4768
    _globals["_IMPLICITOAUTHFLOW"]._serialized_end = 4937
    _globals["_IMPLICITOAUTHFLOW_SCOPESENTRY"]._serialized_start = 4538
    _globals["_IMPLICITOAUTHFLOW_SCOPESENTRY"]._serialized_end = 4583
    _globals["_PASSWORDOAUTHFLOW"]._serialized_start = 4940
    _globals["_PASSWORDOAUTHFLOW"]._serialized_end = 5101
    _globals["_PASSWORDOAUTHFLOW_SCOPESENTRY"]._serialized_start = 4538
    _globals["_PASSWORDOAUTHFLOW_SCOPESENTRY"]._serialized_end = 4583
    _globals["_SENDMESSAGEREQUEST"]._serialized_start = 5104
    _globals["_SENDMESSAGEREQUEST"]._serialized_end = 5273
    _globals["_GETTASKREQUEST"]._serialized_start = 5275
    _globals["_GETTASKREQUEST"]._serialized_end = 5335
    _globals["_CANCELTASKREQUEST"]._serialized_start = 5337
    _globals["_CANCELTASKREQUEST"]._serialized_end = 5370
    _globals["_GETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 5372
    _globals["_GETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 5424
    _globals["_DELETETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 5426
    _globals["_DELETETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 5481
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 5484
    _globals["_CREATETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 5630
    _globals["_TASKSUBSCRIPTIONREQUEST"]._serialized_start = 5632
    _globals["_TASKSUBSCRIPTIONREQUEST"]._serialized_end = 5671
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 5673
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 5767
    _globals["_GETAGENTCARDREQUEST"]._serialized_start = 5769
    _globals["_GETAGENTCARDREQUEST"]._serialized_end = 5790
    _globals["_SENDMESSAGERESPONSE"]._serialized_start = 5792
    _globals["_SENDMESSAGERESPONSE"]._serialized_end = 5895
    _globals["_STREAMRESPONSE"]._serialized_start = 5898
    _globals["_STREAMRESPONSE"]._serialized_end = 6112
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGRESPONSE"]._serialized_start = 6114
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGRESPONSE"]._serialized_end = 6232
    _globals["_A2ASERVICE"]._serialized_start = 6549
    _globals["_A2ASERVICE"]._serialized_end = 7887
# @@protoc_insertion_point(module_scope)
